use std::collections::HashMap;

use banner_pattern::BannerPattern;
use chat_type::ChatType;
use damage_type::DamageType;
use dimension_type::DimensionType;
use painting_variant::PaintingVariant;
use trim_material::TrimMaterial;
use trim_pattern::TrimPattern;
use wolf_variant::WolfVariant;
use worldgen::biome::Biome;

use crate::identifier::Identifier;

pub mod banner_pattern;
pub mod chat_type;
pub mod damage_type;
pub mod dimension_type;
pub mod painting_variant;
pub mod trim_material;
pub mod trim_pattern;
pub mod wolf_variant;
pub mod worldgen;

pub type Registry<T> = HashMap<Identifier, T>;

#[derive(Default)]
pub struct Registries {
    pub trim_materials: Registry<TrimMaterial>,
    pub trim_patterns: Registry<TrimPattern>,
    pub banner_patterns: Registry<BannerPattern>,
    pub worldgen: WorldgenRegistries,
    pub dimension_types: Registry<DimensionType>,
    pub damage_types: Registry<DamageType>,
    pub painting_variants: Registry<PaintingVariant>,
    pub wolf_variants: Registry<WolfVariant>,
    pub chat_types: Registry<ChatType>,
}

impl Registries {
    pub fn empty() -> Registries {
        Self::default()
    }
}

#[derive(Default)]
pub struct WorldgenRegistries {
    pub biomes: Registry<Biome>,
}
